@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #ifndef _COMMAND_LINE_H_
 #define _COMMAND_LINE_H_
@@ -25,6 +25,7 @@ std::vector<std::pair<std::string, std::string> >
 GetShortcutsUsage(const std::string &ctrl = "");
 std::vector<std::pair<std::string, std::string> > GetMouseUsage();
 void PrintUsage(const std::string &name);
+void PrintInfo();
 void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError);
 
 #endif
