@@ -27,11 +27,12 @@ struct contextMeshOptions {
   double anisoMax, smoothRatio;
   int lcFromPoints, lcFromCurvature, lcExtendFromBoundary;
   int nbSmoothing, algo2d, algo3d, algoSubdivide;
-  int algoRecombine, recombineAll, recombine3DAll, recombine3DLevel;
+  int algoRecombine, recombineAll, recombineOptimizeTopology;
+  int recombine3DAll, recombine3DLevel;
   int recombine3DConformity, flexibleTransfinite;
   int order, secondOrderLinear, secondOrderIncomplete, secondOrderExperimental;
   int meshOnlyVisible, minCircPoints, minCurvPoints;
-  int hoOptimize, hoPeriodic, hoNLayers, hoOptPrimSurfMesh;
+  int hoOptimize, hoPeriodic, hoNLayers, hoPrimSurfMesh, hoIterMax, hoPassMax;
   double hoThresholdMin, hoThresholdMax, hoPoissonRatio;
   std::map<int, int> algo2dPerFace;
   std::map<int, int> curvatureControlPerFace;
@@ -44,6 +45,7 @@ struct contextMeshOptions {
   int fileFormat;
   double mshFileVersion, medFileMinorVersion, scalingFactor;
   int saveAll, saveTri, saveGroupsOfNodes, binary, bdfFieldFormat;
+  int unvStrictFormat, stlRemoveDuplicateTriangles;
   int saveParametric, saveTopology, zoneDefinition;
   int saveElementTagType, switchElementTags;
   int cgnsImportOrder, cgnsConstructTopology;
@@ -57,10 +59,6 @@ struct contextMeshOptions {
   int partitionPriWeight, partitionPyrWeight, partitionTrihWeight;
   int partitionOldStyleMsh2;
   int metisAlgorithm, metisEdgeMatching, metisRefinementAlgorithm;
-  // recombination
-  int doRecombinationTest, recombinationTestStart;
-  int recombinationTestNoGreedyStrat, recombinationTestNewStrat, nProc, nbProc;
-  std::string recTestName;
   // mesh display
   int draw, changed, light, lightTwoSide, lightLines, pointType;
   int points, lines, triangles, quadrangles, tetrahedra, hexahedra, prisms;
