@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <stack>
 #include <set>
@@ -29,11 +29,17 @@
 
 bool topoExists(GModel *gm)
 {
-  std::vector<GEntity *> entities;
-  gm->getEntities(entities);
-  std::set<MVertex *> vs;
-  for(unsigned int i = 0; i < entities.size(); i++) {
-    if(entities[i]->vertices().empty()) return false;
+  for(GModel::eiter it = gm->firstEdge(); it != gm->lastEdge(); it++) {
+    GEdge *ge = *it;
+    if(ge->getBeginVertex() == NULL && ge->getEndVertex() == NULL) return false;
+  }
+  for(GModel::fiter it = gm->firstFace(); it != gm->lastFace(); it++) {
+    GFace *gf = *it;
+    if(gf->edges().empty()) return false;
+  }
+  for(GModel::riter it = gm->firstRegion(); it != gm->lastRegion(); it++) {
+    GRegion *gr = *it;
+    if(gr->faces().empty()) return false;
   }
   return true;
 }
@@ -258,9 +264,8 @@ void createTopologyFromMesh1D(GModel *gm, int &num)
       if(gEdgesToGVertex.find(gEdges) == gEdgesToGVertex.end()) {
         num++;
 
-        discreteVertex *dv =
-          new discreteVertex(gm, gm->getMaxElementaryNumber(0) + 1,
-                             mv->x(), mv->y(), mv->z());
+        discreteVertex *dv = new discreteVertex(
+          gm, gm->getMaxElementaryNumber(0) + 1, mv->x(), mv->y(), mv->z());
         gm->add(dv);
 
         mVertexToGVertex[mv] = dv;
@@ -281,6 +286,7 @@ void createTopologyFromMesh1D(GModel *gm, int &num)
 
   // link all GEdge to GVertex and vice versa
   // we expect to see two GVertex per GEdge
+  // unless it is periodic !!!!
 
   for(GEdgeToGVerticesMap::iterator gEIter = gEdgeToGVertices.begin();
       gEIter != gEdgeToGVertices.end(); ++gEIter) {
@@ -300,8 +306,12 @@ void createTopologyFromMesh1D(GModel *gm, int &num)
 
     else {
       std::vector<GEdge *> splits = ensureSimplyConnectedEdge(ge);
-
-      if(splits.size() == 1) {
+      if(splits.size() == 1) { // periodic case
+        GVertex *gv1 = *(gVerts.begin());
+        ge->setBeginVertex(gv1);
+        gv1->addEdge(ge);
+      }
+      else {
         std::ostringstream gVertexList;
         for(std::set<GVertex *>::iterator gvIter = gVerts.begin();
             gvIter != gVerts.end(); ++gvIter) {
@@ -321,9 +331,8 @@ void createTopologyFromMesh1D(GModel *gm, int &num)
     if(!(*it)->getBeginVertex() && !(*it)->getEndVertex()) {
       num++;
       MVertex *v = (*it)->lines[0]->getVertex(0);
-      discreteVertex *dv =
-        new discreteVertex(gm, gm->getMaxElementaryNumber(0) + 1,
-                           v->x(), v->y(), v->z());
+      discreteVertex *dv = new discreteVertex(
+        gm, gm->getMaxElementaryNumber(0) + 1, v->x(), v->y(), v->z());
       gm->add(dv);
       MPoint *mp = new MPoint(v);
       dv->points.push_back(mp);
@@ -417,6 +426,8 @@ void createTopologyFromMesh2D(GModel *gm, int &num)
   for(it = tEdgeToGFaces.begin(); it != tEdgeToGFaces.end(); ++it) {
     std::set<GFace *> &gfaces = it->second;
 
+    //    printf("%d faces\n",gfaces.size());
+
     if(gfaces.size() > 1) {
       GFacesToGEdgeMap::iterator gfIter = gFacesToGEdge.find(gfaces);
 
@@ -695,7 +706,7 @@ void GModel::createTopologyFromMeshNew()
   if(dim >= 2) createTopologyFromMesh2D(this, numE);
   if(dim >= 1) createTopologyFromMesh1D(this, numV);
 
-  _associateEntityWithMeshVertices();
+  _associateEntityWithMeshVertices(true); // force
 
   std::vector<GEntity *> entities;
   getEntities(entities);
