@@ -16,6 +16,7 @@ protected:
   std::vector<MLine *> discrete_lines;
   void orderMLines();
   bool getLocalParameter(const double &t, int &iEdge, double &tLoc) const;
+  discreteEdge *_split[2];
 
 public:
   discreteEdge(GModel *model, int num, GVertex *_v0, GVertex *_v1);
@@ -29,8 +30,23 @@ public:
   virtual Range<double> parBounds(int) const;
   void createGeometry();
   virtual void mesh(bool verbose);
-  void writeGEO(FILE *fp);
   int minimumDrawSegments() const { return 2 * _pars.size(); }
+  virtual int minimumMeshSegments() const { return periodic(0) ? 3: 2;}
+  void setSplit (discreteEdge *e0, discreteEdge *e1) {
+    _split[0] = e0;
+    _split[1] = e1;
+  }
+  void getSplit (std::vector<GEdge*> & s) {
+    if (_split[0] == NULL){
+      if (std::find(s.begin(),s.end(),this) == s.end())
+	s.push_back(this);
+    }
+    else {
+      _split[0]->getSplit(s);
+      _split[1]->getSplit(s);
+    }
+  }
+
 };
 
 #endif
