@@ -826,6 +826,8 @@ try:
 except:
     pass
 
+# Utility functions, not part of the Gmsh Python API
+
 def _ostring(s):
     sp = s.value.decode("utf-8")
     lib.{5}Free(s)
@@ -925,6 +927,7 @@ def _ivectorvectordouble(os):
 def _iargcargv(o):
     return c_int(len(o)), (c_char_p * len(o))(*(s.encode() for s in o))
 
+# Gmsh Python API begins here
 """
 
 julia_header = """# {0}
@@ -1006,7 +1009,7 @@ class API:
                              ", ".join(list((a.c for a in args + (oint("ierr"), )))) +
                              ")\n{\n")
                     if rtype:
-                        fc.write("  " + rtype.rc_type + " result_api_;\n")
+                        fc.write("  " + rtype.rc_type + " result_api_ = 0;\n")
                     fc.write("  if(ierr) *ierr = 0;\n");
                     fc.write("  try {\n");
                     fc.write("".join((a.c_pre for a in args)))
