@@ -1,4 +1,4 @@
-// Copyright (C) 2013 ULg-UCL
+// HighOrderMeshOptimizer - Copyright (C) 2013-2019 UCLouvain-ULiege
 //
 // Permission is hereby granted, free of charge, to any person
 // obtaining a copy of this software and associated documentation
@@ -31,20 +31,23 @@ class GModel;
 
 struct FastCurvingParameters {
   enum OUTERBLCURVE { OUTER_NOCURVE, OUTER_CURVE, OUTER_CURVECONSERVATIVE };
-  int dim ;                       // Spatial dimension of the mesh to curve
-  bool thickness;                 // Curve boundary layer with new algo (experimental)
-  bool onlyVisible ;              // Apply curving to visible entities ONLY?
-  bool optimizeGeometry;          // Optimize boundary edges/faces to fit geometry?
-  OUTERBLCURVE curveOuterBL;      // Curve also the outer surface of the boundary layer?
-  int maxNumLayers;               // Maximum number of layers of elements to curve in BL
-  double maxRho;                  // Maximum ratio min/max edge/face size for elements to curve in BL
-  double maxAngle;                // Maximum angle between layers of elements to curve in BL
-  double maxAngleInner;           // Maximum angle between edges/faces within layers of triangles/tets to curve in BL
+  int dim; // Spatial dimension of the mesh to curve
+  bool thickness; // Curve boundary layer with new algo (experimental)
+  bool onlyVisible; // Apply curving to visible entities ONLY?
+  bool optimizeGeometry; // Optimize boundary edges/faces to fit geometry?
+  OUTERBLCURVE
+    curveOuterBL; // Curve also the outer surface of the boundary layer?
+  int maxNumLayers; // Maximum number of layers of elements to curve in BL
+  double
+    maxRho; // Maximum ratio min/max edge/face size for elements to curve in BL
+  double maxAngle; // Maximum angle between layers of elements to curve in BL
+  double maxAngleInner; // Maximum angle between edges/faces within layers of
+                        // triangles/tets to curve in BL
 
-  FastCurvingParameters () :
-    dim(3), onlyVisible(true), optimizeGeometry(false),
-    curveOuterBL(OUTER_NOCURVE), maxNumLayers(100), maxRho(0.3),
-    maxAngle(3.1415927*10./180.), maxAngleInner(3.1415927*30./180.)
+  FastCurvingParameters()
+    : dim(3), onlyVisible(true), optimizeGeometry(false),
+      curveOuterBL(OUTER_NOCURVE), maxNumLayers(100), maxRho(0.3),
+      maxAngle(3.1415927 * 10. / 180.), maxAngleInner(3.1415927 * 30. / 180.)
   {
   }
 };
